﻿using System;
using System.Runtime.InteropServices; // DLL Import

/// <summary>
/// --------------------------------------------------------------------------
///   RT-edge system / Container
/// 
///   EgFINS.exe(W)
///       OMROM PLC series data connector service
/// 
///   Copyright(c) Micronet Corp 2022, Programmed by Kazumi.M
/// 
/// 
///   -Winsock Wrapper module
///   
///             Windows socket (winsock) initializer
///     
///   
///   -FINS protocol libraly Wrapper module
///   
///            libfins --- Opensource software MIT Licensed
///                        Copyright(c) 2016 Lammert Bies
///            
///            Non-blocking customized by Kazumi.M
/// --------------------------------------------------------------------------
/// </summary>
namespace EgFINS
{
    /// <summary>
    /// WinSockラッパー
    /// </summary>
    public class WinSock
    {
        [StructLayout(LayoutKind.Sequential, Pack = 4)]
        struct WSAData
        {
            public short wVersion;
            public short wHighVersion;
            [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 257)]
            public string szDescription;
            [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 129)]
            public string szSystemStatus;
            public UInt16 iMaxSockets;
            public UInt16 iMaxUdpDg;
            public int lpVendorInfo;
        }

        /// <summary>
        /// かの有名なWSAStartup
        /// </summary>
        /// <param name="wVersionRequested"></param>
        /// <param name="lpWSAData"></param>
        /// <returns></returns>
        [DllImport("wsock32.dll")]
        static extern int WSAStartup([In] short wVersionRequested, [Out] out WSAData lpWSAData);

        /// <summary>
        /// 終了時に使用
        /// </summary>
        /// <returns></returns>
        [DllImport("wsock32.dll")]
        static extern int WSACleanup();

        /// <summary>
        /// Winsockの使用開始で使います
        /// </summary>
        static public void Startup()
        {
            WSAData dummy = new WSAData();
            WSAStartup(0x0202, out dummy);
        }

        /// <summary>
        /// Winsockの使用を終えたときに使用
        /// </summary>
        static public void Cleanup()
        {
            WSACleanup();
        }
    }

    /// <summary>
    /// LibFINSラッパー
    /// </summary>
    public class FinsConnecton
    {
        IntPtr sys;

        /// <summary>
        /// PLC構成情報
        /// </summary>
        [StructLayout(LayoutKind.Sequential, CharSet = CharSet.Ansi)]
        public struct fins_cpudata_tp
        {
            [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 21)]
            public string model;
            [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 21)]
            public string version;
            [MarshalAs(UnmanagedType.ByValArray, SizeConst = 40)]
            public char[] system_block;
            public int largest_em_bank;
            public int program_area_size;
            public int iom_size;
            public int number_of_dm_words;
            public int timer_counter_size;
            public int em_non_file_memory_size;
            public int memory_card_size;
            public int num_sysmac_bus_masters;
            public int num_racks;
            [MarshalAs(UnmanagedType.ByValArray, SizeConst = 16)]
            public UInt16[] bus_unit_id;
            [MarshalAs(UnmanagedType.ByValArray, SizeConst = 16)]
            public bool[] bus_unit_present;
            [MarshalAs(UnmanagedType.ByValArray, SizeConst = 8)]
            public bool[] dip_switch;
            public byte memory_card_type;
        };

        /// <summary>
        /// MultiRead用のパラメータ構造体
        /// </summary>
        [StructLayout(LayoutKind.Sequential , CharSet=CharSet.Ansi)]
        public struct fins_multidata_tp
        {
            [MarshalAs(UnmanagedType.ByValTStr, SizeConst = 12)]
            public string address;
            public int type;
            public UInt64 value;
        };

        /// <summary>
        /// MultiReadで使用するFINS既定のデータ型
        /// </summary>
        public const int FINS_DATA_TYPE_NONE = 0;			/* No data type						*/
        public const int FINS_DATA_TYPE_INT16 = 1;			/* 16 bit signed integer				*/
        public const int FINS_DATA_TYPE_INT32 = 2;			/* 32 bit signed integer				*/
        public const int FINS_DATA_TYPE_UINT16 = 3;			/* 16 bit unsigned integer				*/
        public const int FINS_DATA_TYPE_UINT32 = 4;			/* 32 bit unsigned integer				*/
        public const int FINS_DATA_TYPE_FLOAT = 15;			/* 32 bit floating point value				*/
        public const int FINS_DATA_TYPE_DOUBLE = 16;		/* 64 bit floating point value				*/
        public const int FINS_DATA_TYPE_BIT = 17;			/* Single bit						*/
        public const int FINS_DATA_TYPE_BIT_FORCED = 18;	/* Single bit with forced status			*/
        public const int FINS_DATA_TYPE_WORD_FORCED = 19;	/* 16 bit word with for each bit the forced status	*/
        public const int FINS_DATA_TYPE_LAST = 19;			/* Last defined data type				*/

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern IntPtr finslib_tcp_connect(IntPtr sys, String address, UInt16 port, Byte local_net, Byte local_node, Byte local_unit, Byte remote_net, Byte remote_node, Byte remote_unit, out int error_val, int error_max);

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern IntPtr finslib_udp_connect(IntPtr sys, String address, UInt16 port, Byte local_net, Byte local_node, Byte local_unit, Byte remote_net, Byte remote_node, Byte remote_unit, out int error_val, int error_max);

        [DllImport("libfinsw.dll")]
        static extern void finslib_disconnect(IntPtr sys);

        [DllImport("libfinsw.dll")]
        static extern int finslib_cpu_unit_data_read(IntPtr sys, ref fins_cpudata_tp cpudata);

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern int finslib_memory_area_read_bit(IntPtr sys, String start, IntPtr data, int num_bit);

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern int finslib_memory_area_read_int16(IntPtr sys, String start, IntPtr data, int num_int16);

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern int finslib_memory_area_read_int32(IntPtr sys, String start, IntPtr data, int num_int32);

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern int finslib_memory_area_read_uint16(IntPtr sys, String start, IntPtr data, int num_uint16);

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern int finslib_memory_area_read_uint32(IntPtr sys, String start, IntPtr data, int num_uint32);

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern int finslib_memory_area_read_word(IntPtr sys, String start, IntPtr data, int num_word);

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern int finslib_multiple_memory_area_read(IntPtr sys, IntPtr item, int num_item);

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern int finslib_memory_area_write_bit(IntPtr sys, String start, IntPtr data, int num_bit);

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern int finslib_memory_area_write_int16(IntPtr sys, String start, IntPtr data, int num_int16);

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern int finslib_memory_area_write_int32(IntPtr sys, String start, IntPtr data, int num_int32);

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern int finslib_memory_area_write_uint16(IntPtr sys, String start, IntPtr data, int num_uint16);

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern int finslib_memory_area_write_uint32(IntPtr sys, String start, IntPtr data, int num_uint32);

        [DllImport("libfinsw.dll", CharSet = CharSet.Ansi)]
        static extern int finslib_memory_area_write_word(IntPtr sys, String start, IntPtr data, int num_word);

        /// <summary>
        /// PLCへの接続 TCP
        /// </summary>
        /// <param name="address">PLC側のIPアドレス</param>
        /// <param name="port">FINS共通ポート番号</param>
        /// <param name="local_net">RTedge側のネットワークアドレス</param>
        /// <param name="local_node">RTedge側のノードアドレス</param>
        /// <param name="local_unit">RTedge側のユニットNo</param>
        /// <param name="remote_net">PLC側のネットワークアドレス</param>
        /// <param name="remote_node">PLC側のノードアドレス</param>
        /// <param name="remote_unit">PLC側のユニットNo</param>
        /// <returns>正常終了時0</returns>
        public int TcpConnect(String address, UInt16 port, Byte local_net, Byte local_node, Byte local_unit, Byte remote_net, Byte remote_node, Byte remote_unit)
        {
            int error_val;
            sys = finslib_tcp_connect(IntPtr.Zero, address, port, local_net, local_node, local_unit, remote_net, remote_node, remote_unit, out error_val, 1);

            if (error_val == 0x0000)
            {
                fins_cpudata_tp cpudata = new fins_cpudata_tp();
                finslib_cpu_unit_data_read(sys, ref cpudata);
            }
            return error_val;
        }

        /// <summary>
        /// PLCへの接続 UDP
        /// </summary>
        /// <param name="address">PLC側のIPアドレス</param>
        /// <param name="port">FINS共通ポート番号</param>
        /// <param name="local_net">RTedge側のネットワークアドレス</param>
        /// <param name="local_node">RTedge側のノードアドレス</param>
        /// <param name="local_unit">RTedge側のユニットNo</param>
        /// <param name="remote_net">PLC側のネットワークアドレス</param>
        /// <param name="remote_node">PLC側のノードアドレス</param>
        /// <param name="remote_unit">PLC側のユニットNo</param>
        /// <returns>正常終了時0</returns>
        public int UdpConnect(String address, UInt16 port, Byte local_net, Byte local_node, Byte local_unit, Byte remote_net, Byte remote_node, Byte remote_unit)
        {
            int error_val;
            sys = finslib_udp_connect(IntPtr.Zero, address, port, local_net, local_node, local_unit, remote_net, remote_node, remote_unit, out error_val, 1);

            if (error_val == 0x0000)
            {
                fins_cpudata_tp cpudata = new fins_cpudata_tp();
                finslib_cpu_unit_data_read(sys, ref cpudata);
            }
            return error_val;
        }

        /// <summary>
        /// PLCの切断
        /// </summary>
        public void Disconnect()
        {
            finslib_disconnect(sys);
        }

        /// <summary>
        /// Multipleリードコマンド（効率よいコマンドを構成してくれる）
        /// </summary>
        /// <param name="item">リード先を示した構造体配列</param>
        /// <param name="num_item">配列数</param>
        /// <returns>正常終了時0、異常時は内部で切断されます</returns>
        public int ReadMultiple(ref fins_multidata_tp[] item, int num_item)
        {
            var size = Marshal.SizeOf(typeof(fins_multidata_tp)) * num_item;
            var ptr = Marshal.AllocCoTaskMem(size);
            IntPtr dst = ptr;
            int i;
            int ret = 0;
            for (i = 0; i < num_item; i++)
            {
                Marshal.StructureToPtr(item[i], dst, false);
                dst = (IntPtr)((long)dst + Marshal.SizeOf(item[i]));
            }
            ret = finslib_multiple_memory_area_read(sys, ptr, num_item);
            if (ret == 0)
            {
                IntPtr src = ptr;
                for (i = 0; i < num_item; i++)
                {
                    item[i] = Marshal.PtrToStructure<fins_multidata_tp>(src);
                    src = (IntPtr)((long)src + Marshal.SizeOf(item[i]));
                }
            }
            Marshal.FreeCoTaskMem(ptr);
            return ret;
        }

        public int WriteBit(String start, ref Byte[] data, int num_bit)
        {
            var size = Marshal.SizeOf(typeof(Byte)) * num_bit;
            var ptr = Marshal.AllocCoTaskMem(size);
            Marshal.Copy(data, 0 ,ptr ,num_bit);
            int ret = finslib_memory_area_write_bit(sys, start, ptr, num_bit);
            Marshal.FreeCoTaskMem(ptr);
            return ret;
        }

        public int WriteInt16(String start, ref Int16[] data, int num_int16)
        {
            var size = Marshal.SizeOf(typeof(Int16)) * num_int16;
            var ptr = Marshal.AllocCoTaskMem(size);
            Marshal.Copy(data, 0, ptr, num_int16);
            int ret = finslib_memory_area_write_int16(sys, start, ptr, num_int16);
            Marshal.FreeCoTaskMem(ptr);
            return ret;
        }

        public int WriteInt32(String start, ref Int32[] data, int num_int32)
        {
            var size = Marshal.SizeOf(typeof(Int32)) * num_int32;
            var ptr = Marshal.AllocCoTaskMem(size);
            Marshal.Copy(data, 0, ptr, num_int32);
            int ret = finslib_memory_area_write_int32(sys, start, ptr, num_int32);
            Marshal.FreeCoTaskMem(ptr);
            return ret;
        }

        public int WriteUInt16(String start, ref UInt16[] data, int num_uint16)
        {
            var size = Marshal.SizeOf(typeof(UInt16)) * num_uint16;
            var buf = new short[num_uint16];
            var ptr = Marshal.AllocCoTaskMem(size);
            var i = 0;
            foreach (var val in buf)
                buf[i] = (short)data[i++];
            Marshal.Copy(buf, 0, ptr, num_uint16);
            int ret = finslib_memory_area_write_uint16(sys, start, ptr, num_uint16);
            Marshal.FreeCoTaskMem(ptr);
            return ret;
        }

        public int WriteUInt32(String start, ref UInt32[] data, int num_uint32)
        {
            var size = Marshal.SizeOf(typeof(Int32)) * num_uint32;
            var buf = new int[num_uint32];
            var ptr = Marshal.AllocCoTaskMem(size);
            var i = 0;
            foreach (var val in buf)
                buf[i] = (int)data[i++];
            Marshal.Copy(buf ,0 ,ptr, num_uint32);
            int ret = finslib_memory_area_write_uint32(sys, start, ptr, num_uint32);
            Marshal.FreeCoTaskMem(ptr);
            return ret;
        }

        public int ReadBit(String start, out Byte[] data, int num_bit)
        {
            data = new Byte[num_bit];
            var size = Marshal.SizeOf(typeof(Byte)) * num_bit;
            var ptr = Marshal.AllocCoTaskMem(size);
            int ret = finslib_memory_area_read_bit(sys, start, ptr, num_bit);
            if (ret == 0)
            {
                Marshal.Copy(ptr, data, 0, num_bit);
            }
            Marshal.FreeCoTaskMem(ptr);
            return ret;
        }

        public int ReadInt16(String start, out Int16[] data, int num_int16)
        {
            data = new Int16[num_int16];
            var size = Marshal.SizeOf(typeof(Int16)) * num_int16;
            var ptr = Marshal.AllocCoTaskMem(size);
            var ret = finslib_memory_area_read_int16(sys, start, ptr, num_int16);
            if (ret == 0)
            {
                Marshal.Copy(ptr, data, 0, num_int16);
            }
            Marshal.FreeCoTaskMem(ptr);
            return ret;
        }

        public int ReadInt32(String start, out Int32[] data, int num_int32)
        {
            data = new Int32[num_int32];
            var size = Marshal.SizeOf(typeof(Int32)) * num_int32;
            var ptr = Marshal.AllocCoTaskMem(size);
            var ret = finslib_memory_area_read_int32(sys, start, ptr, num_int32);
            if (ret == 0)
            {
                Marshal.Copy(ptr, data, 0, num_int32);
            }
            Marshal.FreeCoTaskMem(ptr);
            return ret;
        }

        public int ReadUInt16(String start, out UInt16[] data, int num_uint16)
        {
            data = new UInt16[num_uint16];
            var buf = new short[num_uint16];
            var size = Marshal.SizeOf(typeof(UInt16)) * num_uint16;
            var ptr = Marshal.AllocCoTaskMem(size);
            var ret = finslib_memory_area_read_uint16(sys, start, ptr, num_uint16);
            if (ret == 0)
            {
                Marshal.Copy(ptr, buf, 0, num_uint16);
                var i = 0;
                foreach (var val in buf)
                    data[i++] = (UInt16)val;
            }
            Marshal.FreeCoTaskMem(ptr);
            return ret;
        }

        public int ReadUInt32(String start, out UInt32[] data, int num_uint32)
        {
            data = new UInt32[num_uint32];
            var buf = new int[num_uint32];
            var size = Marshal.SizeOf(typeof(UInt32)) * num_uint32;
            var ptr = Marshal.AllocCoTaskMem(size);
            var ret = finslib_memory_area_read_uint32(sys, start, ptr, num_uint32);
            if (ret == 0)
            {
                Marshal.Copy(ptr, buf, 0, num_uint32);
                var i = 0;
                foreach (var val in data)
                    data[i++] = (UInt32)val;
            }
            Marshal.FreeCoTaskMem(ptr);
            return ret;
        }

    }
}
